intelmq.bots.collectors.github_api package — intelmq 2.3.3.alpha1 documentation

# intelmq.bots.collectors.github_api package

## Submodules

## intelmq.bots.collectors.github_api.collector_github_api module

GITHUB API Collector bot

class `intelmq.bots.collectors.github_api.collector_github_api.` `GithubAPICollectorBot`(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.CollectorBot`

  `github_api`(api_path: str, **kwargs) → dict
  `init`()
  `process`()
  `process_request`()

    Requests github API with specific path and functionality

## intelmq.bots.collectors.github_api.collector_github_contents_api module

GITHUB contents API Collector bot

param ‘basic_auth_username’

  github Basic authentication username (REQUIRED)

param ‘basic_auth_password’

  github Basic authentication password (REQUIRED)

param ‘repository’

  only one format (‘<author>/<repo>’) is acceptable (REQUIRED)

param ‘extra_fields’

  comma-separated list of fields to extract from file (DEFAULT = [])

param ‘regex’

  file regex (DEFAULT = ‘*.json’)

`intelmq.bots.collectors.github_api.collector_github_contents_api.` `BOT`

  alias of `intelmq.bots.collectors.github_api.collector_github_contents_api.GithubContentsAPICollectorBot`

class `intelmq.bots.collectors.github_api.collector_github_contents_api.` `GithubContentsAPICollectorBot`(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.bots.collectors.github_api.collector_github_api.GithubAPICollectorBot`

  `init`()
  `process_request`()

    Requests github API with specific path and functionality

## Module contents